/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMParser.h"
#include "DOMWindow.h"
#include "Document.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomDOMParser.h"
#include "gdom/GdomDocument.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomDOMParser.h"
#include "gdom/PrivateGdomDocument.h"
#include "gdom/PrivateIntGdomDOMParser.h"
#include "gdom/PrivateIntGdomDocument.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::DOMParser* obj)
{
    return WebCore::cacheDOMObject<WebCore::DOMParser, GDOMDOMParser>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMDOMParser::GDOMDOMParser(PassRefPtr<WebCore::DOMParser> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMDOMParser::~GDOMDOMParser()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

GdomDocument *
gdom_dom_parser_parse_from_string (GdomDOMParser *thiz, gchar * str, gchar * content_type)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::DOMParser * item = (gdom_dom_parser_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (str, 0);
    g_return_val_if_fail (content_type, 0);
    WebCore::String _g_str = WebCore::String::fromUTF8(str);
    WebCore::String _g_content_type = WebCore::String::fromUTF8(content_type);
    PassRefPtr<WebCore::Document> g_res = WTF::getPtr(item->parseFromString(_g_str, _g_content_type));
    GdomDocument * res = static_cast<GdomDocument *>(WebCore::toGDOM(g_res.get()));
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "DOMParser.h"
#include <gdom/GdomDOMParser.h>
#include <gdom/PrivateGdomDOMParser.h>
#include <gdom/PrivateIntGdomDOMParser.h>
#include <gdom/GdomDOMParserprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomDOMParser, gdom_dom_parser, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomDOMParserPrivate {
    class WebCore::DOMParser *item;
};

#define GDOM_DOM_PARSER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_DOM_PARSER, GdomDOMParserPrivate))
*/
G_END_DECLS
WebCore::DOMParser *
gdom_dom_parser_get_private(GdomDOMParser *request)
{
    GDOMDOMParser *res;
    res = static_cast<GDOMDOMParser*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::DOMParser*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_dom_parser_finalize(GObject* object)
{
    /*GdomDOMParser* request = GDOM_DOM_PARSER(object);*/
    /*GdomDOMParserPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_dom_parser_parent_class)->finalize(object);
}

static void gdom_dom_parser__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomDOMParser *self = GDOM_DOM_PARSER(object);
    WebCore::DOMParser * gself = (gdom_dom_parser_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_dom_parser__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomDOMParser *self = GDOM_DOM_PARSER(object);
    WebCore::DOMParser * gself = (gdom_dom_parser_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_dom_parser_class_init(GdomDOMParserClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_dom_parser_finalize;
    g_klass->set_property = gdom_dom_parser__set_property_fn;
    g_klass->get_property = gdom_dom_parser__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomDOMParserPrivate));*/
}

static void gdom_dom_parser_init(GdomDOMParser* request)
{
    /*GdomDOMParserPrivate* priv = GDOM_DOM_PARSER_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

